%global pypi_name joblib

%global common_description						\
Joblib is a set of tools to provide lightweight pipelining in Python.	\
In particular, joblib offers:						\
 * transparent disk-caching of the output values and lazy		\
   re-evaluation (memorize pattern)					\
 * easy simple parallel computing					\
 * logging and tracing of the execution

# Sources from PYPI doesn't have all needed files for doc build
%bcond_with doc

Name:          python-%{pypi_name}
Version:       1.3.2
Release:       %mkrel 2
Summary:       Lightweight pipelining: using Python functions as pipeline jobs
License:       BSD
Group:         Development/Python

URL:           https://pypi.org/project/joblib/#files
Source0:       %{pypi_source}
BuildArch:     noarch


%description
%{common_description}.


%package -n python3-%{pypi_name}
Summary:       %{summary}
BuildArch:     noarch
BuildRequires:  pyproject-rpm-macros
BuildRequires: pkgconfig(python3)
BuildRequires:  python3-devel

# for docs
%if %{with doc}
BuildRequires: python3dist(sphinx)
BuildRequires: python3dist(sphinx-gallery)
BuildRequires: python3dist(sphinx-rtd-theme)
BuildRequires: python3dist(numpydoc)
%endif

Requires:      python3-numpy

%description -n python3-%{pypi_name}
%{common_description}.


%prep
%autosetup -n %{pypi_name}-%{version} -p1


%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%if %{with doc}
PYTHONPATH=$(pwd) sphinx-build -b html doc doc/_build/html/
rm -rf doc/_build/html/.buildinfo
%endif

%install
%pyproject_install
%pyproject_save_files joblib

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE.txt
%doc README.rst
%if %{with doc}
%doc doc/_build/html/
%endif


%changelog
* Wed Jan 31 2024 papoteur <papoteur> 1.3.2-2.mga10
+ Revision: 2036494
- rebuild for python 3.12

* Sun Oct 22 2023 papoteur <papoteur> 1.3.2-1.mga10
+ Revision: 2000199
- new 1.3.2

* Sun Oct 02 2022 neoclust <neoclust> 1.2.0-1.mga9
+ Revision: 1894132
- New version 1.2.0

* Mon Mar 28 2022 umeabot <umeabot> 1.1.0-2.mga9
+ Revision: 1829571
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 mrambo3501 <mrambo3501> 1.1.0-1.mga9
+ Revision: 1782677
- version 1.1.0
- rebuild for python-3.10

* Sun Mar 21 2021 guillomovitch <guillomovitch> 1.0.1-1.mga9
+ Revision: 1707142
- new version 1.0.1

* Fri Dec 18 2020 joequant <joequant> 1.0.0-1.mga8
+ Revision: 1660570
- update to 1.0.0

* Sun Feb 16 2020 umeabot <umeabot> 0.13.2-4.mga8
+ Revision: 1533722
- Mageia 8 Mass Rebuild

* Tue Sep 24 2019 tv <tv> 0.13.2-3.mga8
+ Revision: 1445350
- Backport all patches from upstream to fix python3.8 compat
- rebuild for python-3.8
- drop python2 subpkg

* Tue Aug 20 2019 wally <wally> 0.13.2-2.mga8
+ Revision: 1430436
- disable doc build
- drop unused pytest BRs

* Sun Apr 21 2019 wally <wally> 0.13.2-1.mga7
+ Revision: 1394230
- new version 0.13.2

* Tue Jan 08 2019 tv <tv> 0.12.2-3.mga7
+ Revision: 1351673
- rebuild with python 3.7

* Thu Sep 20 2018 umeabot <umeabot> 0.12.2-2.mga7
+ Revision: 1289153
- Mageia 7 Mass Rebuild

* Thu Aug 16 2018 eatdirt <eatdirt> 0.12.2-1.mga7
+ Revision: 1251942
- Upgrade to version 0.12.2

* Sat Aug 05 2017 pterjan <pterjan> 0.9.0b4-3.mga7
+ Revision: 1135465
- Rebuild for python 3.6

* Sat Feb 20 2016 umeabot <umeabot> 0.9.0b4-2.mga6
+ Revision: 971187
- Mageia 6 Mass Rebuild

* Sun Oct 11 2015 shlomif <shlomif> 0.9.0b4-1.mga6
+ Revision: 889661
- New version 0.9.0 + Rebuild for Python3 3.5.x
+ tv <tv>
- rebuild for python 3.5

* Mon Dec 22 2014 joequant <joequant> 0.8.3-1.mga5
+ Revision: 804763
- fix group
- imported package python-joblib

